class Batch < ActiveRecord::Base
  belongs_to :course

  has_many :students
  has_many :archived_students
  has_many :grading_levels, :conditions => { :is_deleted => false }
  has_many :subjects, :conditions => { :is_deleted => false }
  has_many :exam_groups
  has_many :fee_category , :class_name => "FinanceFeeCategory"
  has_many :elective_groups
  has_many :additional_exam_groups

  has_and_belongs_to_many :graduated_students, :class_name => 'Student', :join_table => 'batch_students'

  delegate :course_name,:section_name, :code, :to => :course

  validates_presence_of :name, :start_date, :end_date

  named_scope :active, :conditions => { :is_deleted => false, :is_active => true }
  named_scope :deleted, :conditions => { :is_deleted => true }

  def validate
    errors.add(:start_date, 'should be before end date.') \
      if self.start_date > self.end_date \
      if self.start_date and self.end_date
  end

  def full_name
    "#{code} - #{section_name}  #{name}"
  end

  def course_section_name
    "#{course_name} - #{section_name}"
  end
  
  def inactivate
    update_attribute(:is_deleted, true)
  end

  def grading_level_list
    levels = self.grading_levels
    levels.empty? ? GradingLevel.default : levels
  end

  def fee_collection_dates
    FinanceFeeCollection.find_all_by_batch_id(self.id,:conditions => "is_deleted = false")
  end

  def all_students
    Student.find_all_by_batch_id(self.id)
  end

  def normal_batch_subject
    Subject.find_all_by_batch_id(self.id,:conditions=>["elective_group_id IS NULL AND is_deleted = false"])
  end
  def elective_batch_subject(elect_group)
    Subject.find_all_by_batch_id_and_elective_group_id(self.id,elect_group,:conditions=>["elective_group_id IS NOT NULL AND is_deleted = false"])
  end
end
